@@ -1,3 +1,4 @@
+import time
 import base64
 import binascii
 import string
@@ -73,7 +74,6 @@ def s12_decrypt(data, password):
     cipher = S12CipherCore(password)
     return cipher.decrypt(data)
 
-
 class MappingCipherBase(object):
     def __init__(self, password):
         self.password = password
@@ -361,6 +361,17 @@ class AesCipher(CipherBase):
         "decrypt": aesutils.decrypt,
     }
 
+class MysqlAesCipher(CipherBase):
+    
+    defaults = {
+        "result_encoder": RawDataEncoder(),
+        "encrypt": aesutils.encrypt,
+        "decrypt": aesutils.decrypt,
+        "kwargs": {
+            "key": mysql_aes_key
+        }
+    }
+
 class S12Cipher(CipherBase):
 
     defaults = {
