@@ -129,11 +129,11 @@ def expand(filename):
     """
     return os.path.abspath(os.path.expandvars(os.path.expanduser(filename)))
 
-def first_exists_file(*filenames):
+def first_exists_file(*filenames, default=None):
     """Return the first exists file's abspath. If none file exists, return None.
     """
     for filename in filenames:
         filename = expand(filename)
         if os.path.exists(filename):
             return filename
-    return None
+    return default
