@@ -112,9 +112,19 @@ def wholestrip(text):
         text = text.replace(space, "")
     return text
 
+def split2(text, sep=None):
+    """Split string into 2 segments.
+    """
+    ss = text.split(sep, 1)
+    if len(ss) == 1:
+        ss.append("")
+    return ss
+
 def split(text, seps, strip=False):
     """seps is a list of string, all sep in the seps are treated as delimiter.
     """
+    if not text:
+        return []
     if not isinstance(seps, (list, set, tuple)):
         seps = [seps]
     results = [text]
@@ -564,3 +574,28 @@ def is_uuid(value):
             return True
         except ValueError:
             return False
+
+def stringlist_append(string_value, new_element, separator=",", allow_duplicate=True):
+    elements = split(string_value, [separator], strip=True)
+    if allow_duplicate or (not new_element in elements):
+        elements.append(new_element)
+    return separator.join(elements)
+
+def html_element_css_append(classes, new_class_name):
+    return stringlist_append(classes, new_class_name, separator=" ", allow_duplicate=False)
+
+
+def remove_prefix(thestring, prefix):
+    if thestring.startswith(prefix):
+        return thestring[len(prefix):]
+    else:
+        return thestring
+
+def remove_suffix(thestring, suffix):
+    if thestring.endswith(suffix):
+        if len(suffix):
+            return thestring[:-len(suffix)]
+        else:
+            return thestring
+    else:
+        return thestring
